Package: Clomial
Type: Package
Title: Infers clonal composition of a tumor
Version: 1.49.0
Date: 2018-05-31
Author: Habil Zare and Alex Hu
Maintainer: Habil Zare <zare@u.washington.edu>
Depends: R (>= 2.10), matrixStats
Imports: methods, permute
Description: Clomial fits binomial distributions to counts obtained
        from Next Gen Sequencing data of multiple samples of the same
        tumor. The trained parameters can be interpreted to infer the
        clonal structure of the tumor.
License: GPL (>= 2)
biocViews: Genetics, GeneticVariability, Sequencing, Clustering,
        MultipleComparison, Bayesian, DNASeq, ExomeSeq,
        TargetedResequencing, ImmunoOncology
LazyLoad: yes
git_url: https://git.bioconductor.org/packages/Clomial
git_branch: devel
git_last_commit: ca3ec4d
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-28 21:52:14 UTC; biocbuild
